/*
 * Part of Intel(R) Manageability Engine Interface Linux driver
 *
 * Copyright (c) 2003 - 2008 Intel Corp.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions, and the following disclaimer,
 *    without modification.
 * 2. Redistributions in binary form must reproduce at minimum a disclaimer
 *    substantially similar to the "NO WARRANTY" disclaimer below
 *    ("Disclaimer") and any redistribution must be conditioned upon
 *    including a substantially similar Disclaimer requirement for further
 *    binary redistribution.
 * 3. Neither the names of the above-listed copyright holders nor the names
 *    of any contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * Alternatively, this software may be distributed under the terms of the
 * GNU General Public License ("GPL") version 2 as published by the Free
 * Software Foundation.
 *
 * NO WARRANTY
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGES.
 *
 */

#ifndef _HECI_H_
#define _HECI_H_

#include "heci_data_structures.h"
#include "heci_interface.h"

extern const struct guid heci_pthi_guid;
extern const struct guid heci_wd_guid;
extern const __u8 heci_start_wd_params[];
extern const __u8 heci_stop_wd_params[];
extern const __u8 heci_wd_state_independence_msg[3][4];

/*
 * heci device ID
 */
#define    HECI_DEV_ID_82946GZ    0x2974  /* 82946GZ/GL */
#define    HECI_DEV_ID_82G35      0x2984  /* 82G35 Express */
#define    HECI_DEV_ID_82Q965     0x2994  /* 82Q963/Q965 */
#define    HECI_DEV_ID_82G965     0x29A4  /* 82P965/G965 */

#define    HECI_DEV_ID_82GM965    0x2A04  /* Mobile PM965/GM965 */
#define    HECI_DEV_ID_82GME965   0x2A14  /* Mobile GME965/GLE960 */

#define    HECI_DEV_ID_ICH9_82Q35 0x29B4  /* 82Q35 Express */
#define    HECI_DEV_ID_ICH9_82G33 0x29C4  /* 82G33/G31/P35/P31 Express */
#define    HECI_DEV_ID_ICH9_82Q33 0x29D4  /* 82Q33 Express */
#define    HECI_DEV_ID_ICH9_82X38 0x29E4  /* 82X38/X48 Express */
#define    HECI_DEV_ID_ICH9_3200  0x29F4  /* 3200/3210 Server */

#define    HECI_DEV_ID_ICH9_6     0x28B4  /* Bearlake */
#define    HECI_DEV_ID_ICH9_7     0x28C4  /* Bearlake */
#define    HECI_DEV_ID_ICH9_8     0x28D4  /* Bearlake */
#define    HECI_DEV_ID_ICH9_9     0x28E4  /* Bearlake */
#define    HECI_DEV_ID_ICH9_10    0x28F4  /* Bearlake */

#define    HECI_DEV_ID_ICH9M_1    0x2A44  /* Cantiga */
#define    HECI_DEV_ID_ICH9M_2    0x2A54  /* Cantiga */
#define    HECI_DEV_ID_ICH9M_3    0x2A64  /* Cantiga */
#define    HECI_DEV_ID_ICH9M_4    0x2A74  /* Cantiga */

#define    HECI_DEV_ID_ICH10_1    0x2E04  /* Eaglelake */
#define    HECI_DEV_ID_ICH10_2    0x2E14  /* Eaglelake */
#define    HECI_DEV_ID_ICH10_3    0x2E24  /* Eaglelake */
#define    HECI_DEV_ID_ICH10_4    0x2E34  /* Eaglelake */
#define    HECI_DEV_ID_ICH10_5    0x2E44  /* Eaglelake */

/*
 * heci init function prototypes
 */
struct iamt_heci_device *init_heci_device(struct pci_dev *pdev);
void heci_reset(struct iamt_heci_device *dev, int interrupts);
int heci_hw_init(struct iamt_heci_device *dev);
int heci_task_initialize_clients(void *data);
int heci_initialize_clients(struct iamt_heci_device *dev);
struct heci_file_priv *heci_alloc_file_priv(struct file *file);
struct heci_connection *heci_alloc_heci_connection(struct file *file);
void heci_put_heci_connection(struct heci_connection *conn);
#define heci_free_heci_connection heci_put_heci_connection
void put_heci_device(struct iamt_heci_device *dev);
#define get_heci_device(dev) atomic_inc(&dev->refcnt)
#define free_heci_device put_heci_device
void heci_initialize_list(struct heci_io_list *list);
int heci_flush_list(struct heci_io_list *list,
		     struct heci_connection *conn,
		     struct heci_cb_private *priv_cb);

/*
 *  interrupt function prototype
 */
irqreturn_t heci_isr_interrupt(int irq, void *dev_id);

void heci_wd_timer(unsigned long data);

int heci_isr_thread(void *data);

/*
 *  input output function prototype
 */
int heci_ioctl_get_version(struct iamt_heci_device *dev,
			   struct heci_message_data *u_msg,
			   struct heci_message_data k_msg);

int heci_ioctl_connect_client(struct iamt_heci_device *dev,
			      struct heci_message_data *u_msg,
			      struct heci_message_data k_msg,
			      struct heci_file_priv *file_ext);

int heci_ioctl_wd(struct iamt_heci_device *dev,
		  struct heci_message_data k_msg);

int heci_ioctl_bypass_wd(struct iamt_heci_device *dev,
		  struct heci_message_data k_msg);

int heci_have_slots(__s32 *slots, __u32 datalen);

int heci_start_read_flow(struct iamt_heci_device *dev,
			 struct heci_connection *conn,
			 struct heci_cb_private *priv_cb,
			 __s32 *slots);

__u32 heci_len_to_slots(__u32 datalen);

int heci_write_buf(struct iamt_heci_device *dev,
		   struct heci_cb_private *priv_cb,
		   struct heci_connection *conn,
		   __u32 wrspace, __u32 maxwrspace, __s32 *slots);

int heci_read_raw(struct iamt_heci_device *dev,
		  struct heci_file_priv *file_ext,
		  struct heci_cb_private *priv_cb,
		  char *ubuf, size_t length, loff_t *offset,
		  unsigned long timeout, int *needfree);

struct heci_cb_private *heci_find_list_conn_entry(
		struct heci_io_list *list,
		struct heci_connection *conn);

struct heci_cb_private *heci_find_list_file_entry(
		struct heci_io_list *list,
		struct file *file);

struct heci_cb_private *heci_find_read_entry(struct iamt_heci_device *dev,
					  struct file *file, __u8 *rcomplete);

int heci_wd(struct iamt_heci_device *dev, __s32 *slots);

/**
 * heci_fe_same_id - tell if file connection data have same id
 *
 * @fe1: connection data of 1. file object
 * @fe2: connection data of 2. file object
 *
 * returns  !=0 - if ids are the same, 0 - if differ.
 */
static inline int heci_fe_same_id(const struct heci_connection *fe1,
				  const struct heci_connection *fe2)
{
	return ((fe1->host_client_id == fe2->host_client_id)
		&& (fe1->me_client_id == fe2->me_client_id));
}

#endif /* _HECI_H_ */
